@@ -1,6 +1,7 @@
 /*
-    Copyright (c) 2007-2011 iMatix Corporation
-    Copyright (c) 2007-2011 Other contributors as noted in the AUTHORS file
+    Copyright (c) 2010-2011 250bpm s.r.o.
+    Copyright (c) 2011 iMatix Corporation
+    Copyright (c) 2010-2011 Other contributors as noted in the AUTHORS file
 
     This file is part of 0MQ.
 
@@ -19,9 +20,12 @@
 */
 
 #include "../include/zmq.h"
-#include <assert.h>
 #include <pthread.h>
 #include <stddef.h>
+#include <stdio.h>
+
+#undef NDEBUG
+#include <assert.h>
 
 #define THREAD_COUNT 100
 
@@ -42,7 +46,7 @@ extern "C"
     }
 }
 
-int main (int argc, char *argv [])
+int main (void)
 {
     void *ctx;
     void *s1;
@@ -52,13 +56,15 @@ int main (int argc, char *argv [])
     int rc;
     pthread_t threads [THREAD_COUNT];
 
+    fprintf (stderr, "test_shutdown_stress running...\n");
+
     for (j = 0; j != 10; j++) {
 
         //  Check the shutdown with many parallel I/O threads.
         ctx = zmq_init (7);
         assert (ctx);
 
-        s1 = zmq_socket (ctx, ZMQ_REP);
+        s1 = zmq_socket (ctx, ZMQ_PUB);
         assert (s1);
 
         rc = zmq_bind (s1, "tcp://127.0.0.1:5560");
